@@ -29,10 +29,12 @@
 #' y %>% feature() %>% geo_bbox()
 #' file <- system.file("examples", 'linestring_one.geojson',
 #'   package = "geojson")
-#' str <- paste0(readLines(file), collapse = " ")
+#' con <- file(file)
+#' str <- paste0(readLines(con), collapse = " ")
 #' (y <- linestring(str))
 #' geo_bbox(y)
 #' y %>% feature() %>% geo_bbox()
+#' close(con)
 #'
 #' # multilinestring
 #' x <- '{ "type": "MultiLineString",
@@ -174,7 +176,7 @@ geo_bbox.geomultipolygon <- function(x) {
 grab_coords <- function(x, str) {
   as.numeric(stex(cchar(unclass(
     jqr::jq(unclass(x), str)
-  )), "[0-9.]+"))
+  )), "-?[0-9.]+"))
 }
 
 make_box <- function(x, y) {
