@@ -2,7 +2,7 @@
 #'
 #' @export
 #' @param x input, an object of class \code{geojson}
-#' @param file (character) a file path
+#' @param file (character) a file path, or connection
 #' @details Wrapper around \code{\link[jsonlite]{toJSON}} and
 #' \code{\link{cat}}
 #' @examples
@@ -24,8 +24,10 @@ geo_write.default <- function(x, file) {
 
 #' @export
 geo_write.geojson <- function(x, file) {
+  if (inherits(file, "file")) on.exit(close(file)) 
   cat(
     jsonlite::toJSON(jsonlite::fromJSON(x), pretty = TRUE, auto_unbox = TRUE),
+    "\n",
     file = file
   )
 }
